==> e107-0.7.20.tbz: www/e107/e107_plugins/chatbox_menu/languages/English/English_config.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/chatbox_menu/languages/English/English_config.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
|     Encoding:
+----------------------------------------------------------------------------+
*/
define("CHBLAN_1", "Chatbox settings updated.");
define("CHBLAN_2", "Moderated.");
define("CHBLAN_3", "No chatbox posts yet.");
define("CHBLAN_4", "Member");
define("CHBLAN_5", "Guest");
define("CHBLAN_6", "unblock");
define("CHBLAN_7", "block");
define("CHBLAN_8", "delete");
define("CHBLAN_9", "Moderate Chatbox");
define("CHBLAN_10", "Moderate posts");
define("CHBLAN_11", "Chatbox posts to display");
define("CHBLAN_12", "amount of posts displayed in chatbox");
define("CHBLAN_13", "Replace links");
define("CHBLAN_14", "if ticked, posted links will be replaced by text entered in box below");
define("CHBLAN_15", "Replace string if activated");
define("CHBLAN_16", "links will be replaced by this string");
define("CHBLAN_17", "Wordwrap count");
define("CHBLAN_18", "words longer than the number you set here will be wrapped");
define("CHBLAN_19", "Update Chatbox Settings");
define("CHBLAN_20", "Chatbox Settings");
define("CHBLAN_21", "Prune");
define("CHBLAN_22", "Delete posts older than a certain time period");
define("CHBLAN_23", "Delete posts older than ");

define("CHBLAN_24", "One day");
define("CHBLAN_25", "One week");
define("CHBLAN_26", "One month");
define("CHBLAN_27", "- Delete all posts -");
define("CHBLAN_28", "Chatbox pruned.");

define("CHBLAN_29", "Display chatbox inside scrolling layer");
define("CHBLAN_30", "Layer height");
define("CHBLAN_31", "Show emoticons");
define("CHBLAN_32", "Moderator userclass");

define("CHBLAN_33", "User counts recalculated");
define("CHBLAN_34", "Recalculate user post counts");
define("CHBLAN_35", "Recalculate");

define("CHBLAN_36", "Chatbox Display options");
define("CHBLAN_37", "Normal chatbox");
define("CHBLAN_38", "Use javascript code to update posts dynamically (AJAX)");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/chatbox_menu/languages/English/English_config.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/chatbox_menu/languages/English/English_config.php $
|     $Revision: 11678 $
|     $Id: English_config.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
|     Encoding:
+----------------------------------------------------------------------------+
*/
define("CHBLAN_1", "Chatbox settings updated.");
define("CHBLAN_2", "Moderated.");
define("CHBLAN_3", "No chatbox posts yet.");
define("CHBLAN_4", "Member");
define("CHBLAN_5", "Guest");
define("CHBLAN_6", "unblock");
define("CHBLAN_7", "block");
define("CHBLAN_8", "delete");
define("CHBLAN_9", "Moderate Chatbox");
define("CHBLAN_10", "Moderate posts");
define("CHBLAN_11", "Chatbox posts to display");
define("CHBLAN_12", "amount of posts displayed in chatbox");
define("CHBLAN_13", "Replace links");
define("CHBLAN_14", "if ticked, posted links will be replaced by text entered in box below");
define("CHBLAN_15", "Replace string if activated");
define("CHBLAN_16", "links will be replaced by this string");
define("CHBLAN_17", "Wordwrap count");
define("CHBLAN_18", "words longer than the number you set here will be wrapped");
define("CHBLAN_19", "Update Chatbox Settings");
define("CHBLAN_20", "Chatbox Settings");
define("CHBLAN_21", "Prune");
define("CHBLAN_22", "Delete posts older than a certain time period");
define("CHBLAN_23", "Delete posts older than ");

define("CHBLAN_24", "One day");
define("CHBLAN_25", "One week");
define("CHBLAN_26", "One month");
define("CHBLAN_27", "- Delete all posts -");
define("CHBLAN_28", "Chatbox pruned.");

define("CHBLAN_29", "Display chatbox inside scrolling layer");
define("CHBLAN_30", "Layer height");
define("CHBLAN_31", "Show emoticons");
define("CHBLAN_32", "Moderator userclass");

define("CHBLAN_33", "User counts recalculated");
define("CHBLAN_34", "Recalculate user post counts");
define("CHBLAN_35", "Recalculate");

define("CHBLAN_36", "Chatbox Display options");
define("CHBLAN_37", "Normal chatbox");
define("CHBLAN_38", "Use javascript code to update posts dynamically (AJAX)");

?>
